@@ -249,7 +249,7 @@ class BufferBase (object):
     from fstd2nc import __version__
     from argparse import SUPPRESS
     from sys import stdout
-    parser.add_argument('--version', action='version', version=__version__)
+    parser.add_argument('--version', action='version', version=__version__, help=_("show program's version number and exit"))
     group = parser.add_mutually_exclusive_group()
     _('Display a progress bar during the conversion, if the "progress" module is installed.')
     group.add_argument('--progress', action='store_true', default=stdout.isatty(), help=SUPPRESS)
@@ -313,6 +313,7 @@ class BufferBase (object):
     from glob import glob, has_magic
     import os
     from multiprocessing import Pool
+    from pathlib import Path
     try:
       from itertools import imap  # Python 2
     except ImportError:
@@ -323,7 +324,7 @@ class BufferBase (object):
 
     self._serial = serial
 
-    if isinstance(filename,str):
+    if isinstance(filename,(str,Path)):
       infiles = [filename]
     else:
       infiles = list(filename)
@@ -331,6 +332,8 @@ class BufferBase (object):
     # Apply wildcard and directory expansion to filenames.
     expanded_infiles = []
     for infile in infiles:
+      if isinstance(infile,Path):
+        infile = str(infile)
       for f in sorted(glob(infile)) or [infile]:
         if os.path.isdir(f):
           for dirpath, dirnames, filenames in os.walk(f,followlinks=True):
@@ -891,6 +894,16 @@ class BufferBase (object):
   def _raw_headers (filename):
     raise NotImplementedError("No decoder found.")
 
+  # Shortcut for reading a record, given a record id.
+  def _read_record (self, rec):
+    import numpy as np
+    with open(self._files[self._headers['file_id'][rec]],'rb') as f:
+      f.seek(self._headers['address'][rec],0)
+      data = np.fromfile(f,'B',self._headers['length'][rec])
+      data = self._decode(data,rec)
+    return data
+
+
   #
   ###############################################
 
