@@ -96,33 +96,6 @@ class Masks (BufferBase):
         except OverflowError:
           warn(_("Can't set fill value '%g' for %s.")%(self._fill_value,var.name))
 
-  # Apply the mask data
-  def _fstluk (self, rec_id, dtype=None, rank=None, dataArray=None):
-    import numpy as np
-    from rpnpy.librmn.fstd98 import fstinf
-    with self._lock:
-      prm = super(Masks,self)._fstluk(rec_id, dtype, rank, dataArray)
-      # If this data is encoded by the datyp+64 flag, then mask out the
-      # largest value, assuming the mask was generated by (max-min)*1.01
-      # or something similar.
-      # TODO: Use the proper interface once it's wrapped in rpnpy.
-      if (prm['datyp'] & 64) == 64:
-        mx = prm['d'].max()
-        prm['d'] = np.where(prm['d']==mx, self._fill_value, prm['d'])
-        return prm
-      # If this data is not masked, or if this record *is* a mask, then just
-      # return it.
-      if not prm['typvar'].endswith('@'): return prm
-      if prm['typvar'] == '@@' : return prm
-      mask_key = fstinf(self._opened_funit, nomvar=prm['nomvar'], typvar = '@@',
-                        datev=prm['datev'], etiket=prm['etiket'],
-                        ip1 = prm['ip1'], ip2 = prm['ip2'], ip3 = prm['ip3'])
-    if mask_key is not None:
-      mask = super(Masks,self)._fstluk(mask_key, rank=rank)['d']
-      prm['d'] *= (mask>0)
-      prm['d'] += self._fill_value * (mask==0)
-    return prm
-
   # Apply the mask data from raw binary array.
   def _decode (self, data, unused):
     import numpy as np
